@@ -12,10 +12,6 @@
 #include "r.transform.template.h"
 #include "analog.h"
 
-using std::cerr;
-using std::endl;
-
-
 SEXP movingMean(SEXP x, SEXP periods) {
   return windowSpecializer<Mean, meanTraits>(x,periods);
 }
@@ -68,11 +64,25 @@ SEXP fillValue(SEXP x, SEXP y) {
   return transformSpecializer_1arg<FillValue, fillTraits>(x, y);
 }
 
+SEXP pad(SEXP x, SEXP padDates) {
+  double* dts = REAL(padDates);
+  switch(TYPEOF(x)) {
+    case REALSXP:
+      return r_convert<REALSXP>::apply(x).pad(dts, dts + length(padDates)).getIMPL()->R_object;
+    case INTSXP:
+      return r_convert<INTSXP>::apply(x).pad(dts, dts + length(padDates)).getIMPL()->R_object;
+    case LGLSXP:
+      return r_convert<LGLSXP>::apply(x).pad(dts, dts + length(padDates)).getIMPL()->R_object;
+    default:
+      return R_NilValue;
+  }
+}
+
 SEXP lag(SEXP x, SEXP periods_sexp) {
   R_len_t periods = Rtype<INTSXP>::scalar(periods_sexp);
 
   if(periods < 0) {
-    cerr << "only positive values of k are allowed" << endl;
+    Rprintf("only positive values of k are allowed.\n");
   }
   try {
     switch(TYPEOF(x)) {
@@ -86,7 +96,7 @@ SEXP lag(SEXP x, SEXP periods_sexp) {
       return R_NilValue;
     }
   } catch(TSeriesError& e) {
-    cerr << e.what() << endl;
+    Rprintf("%s\n",e.what());
     return R_NilValue;
   }
 }
@@ -95,7 +105,7 @@ SEXP lead(SEXP x, SEXP periods_sexp) {
   R_len_t periods = Rtype<INTSXP>::scalar(periods_sexp);
 
   if(periods < 0) {
-    cerr << "only positive values of k are allowed" << endl;
+    Rprintf("only positive values of k are allowed.\n");
   }
   try {
     switch(TYPEOF(x)) {
@@ -109,7 +119,7 @@ SEXP lead(SEXP x, SEXP periods_sexp) {
       return R_NilValue;
     }
   } catch(TSeriesError& e) {
-    cerr << e.what() << endl;
+    Rprintf("%s\n",e.what());
     return R_NilValue;
   }
 }
@@ -118,7 +128,7 @@ SEXP diff(SEXP x, SEXP periods_sexp) {
   R_len_t periods = Rtype<INTSXP>::scalar(periods_sexp);
 
   if(periods < 0) {
-    cerr << "only positive values of k are allowed" << endl;
+    Rprintf("only positive values of k are allowed.\n");
   }
   try {
     switch(TYPEOF(x)) {
@@ -132,7 +142,7 @@ SEXP diff(SEXP x, SEXP periods_sexp) {
       return R_NilValue;
     }
   } catch(TSeriesError& e) {
-    cerr << e.what() << endl;
+    Rprintf("%s\n",e.what());
     return R_NilValue;
   }
 }
